import * as ts from "typescript";
import { LogLevel } from "simplr-logger";
import { ApiItem, ApiItemOptions } from "./abstractions/api-item";
import { ApiItemReference } from "./contracts/api-item-reference";
import { TypeDto } from "./contracts/type-dto";
import { AccessModifier } from "./contracts/access-modifier";
import { ApiItemLocationDto } from "./contracts/api-item-location-dto";
export declare namespace ApiHelpers {
    function VisitApiItem(declaration: ts.Declaration, symbol: ts.Symbol, options: ApiItemOptions): ApiItem | undefined;
    const NODE_MODULES_PACKAGE_REGEX: RegExp;
    function ShouldVisit(declaration: ts.Declaration, options: ApiItemOptions): boolean;
    function GetItemId(declaration: ts.Declaration, symbol: ts.Symbol, options: ApiItemOptions): string | undefined;
    function GetItemsIdsFromSymbolsMap(symbols: ts.UnderscoreEscapedMap<ts.Symbol> | undefined, options: ApiItemOptions): ApiItemReference[];
    function GetItemIdsFromSymbol(symbol: ts.Symbol | undefined, options: ApiItemOptions): ApiItemReference | undefined;
    function GetItemsIdsFromDeclarations(declarations: ts.NodeArray<ts.Declaration>, options: ApiItemOptions): ApiItemReference[];
    type HeritageKinds = ts.SyntaxKind.ImplementsKeyword | ts.SyntaxKind.ExtendsKeyword;
    function GetHeritageList(heritageClauses: ts.NodeArray<ts.HeritageClause>, kind: HeritageKinds, options: ApiItemOptions): TypeDto[];
    function TypeToApiTypeDto(type: ts.Type, options: ApiItemOptions): TypeDto;
    function ResolveAccessModifierFromModifiers(modifiers?: ts.NodeArray<ts.Modifier>): AccessModifier;
    function ModifierKindExistsInModifiers(modifiers: ts.NodeArray<ts.Modifier> | undefined, kind: ts.SyntaxKind): boolean;
    function LogWithNodePosition(logLevel: LogLevel, declaration: ts.Node, message: string): void;
    function StandardizeRelativePath(location: string, options: ApiItemOptions): string;
    function GetApiItemLocationDtoFromNode(node: ts.Node, options: ApiItemOptions): ApiItemLocationDto;
}
